==> ksniffer_0.3.orig.tar.gz: ksniffer-0.3.orig/ksniffer/protocols/udp-protocol.cpp <==
/***************************************************************************
 *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
 *   giovanni@ksniffer.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA  02110-1301, USA.          *
 ***************************************************************************/

#include <netinet/in.h>

#include <qstringlist.h>

#include <klocale.h>

#include "udp-protocol.h"
#include "protocolnamelist.h"
#include "../packet.h"
#include "../packetstructures.h"

UdpProtocol::UdpProtocol(Packet *packet, ProtocolNameList *pnl)
{
  m_packet = packet;
  m_protocolNameList = pnl;
}


u_int16_t UdpProtocol::sourcePort() const
{
  struct UdpHdr *udp = (struct UdpHdr *) m_packet;

  return ntohs(udp->uh_sport);
}


u_int16_t UdpProtocol::destinationPort() const
{
  struct UdpHdr *udp = (struct UdpHdr *) m_packet;

  return ntohs(udp->uh_dport);
}


u_int16_t UdpProtocol::length() const
{
  struct UdpHdr *udp = (struct UdpHdr *) m_packet;

  return ntohs(udp->uh_ulen);
}


u_int16_t UdpProtocol::checksum() const
{
  struct UdpHdr *udp = (struct UdpHdr *) m_packet;

  return ntohs(udp->uh_sum);
}


QStringList UdpProtocol::headerLines() const
{
  QStringList list;
  QString protocol;

  protocol = m_protocolNameList->detectProtocol( sourcePort() );
  if ( protocol.isEmpty() )
    list << i18n("UDP protocol field", "Source port: %1").arg( sourcePort() );
  else
    list << i18n("UDP protocol field", "Source port: %1 (%2)").arg( sourcePort() ).arg( protocol );

  protocol = m_protocolNameList->detectProtocol( destinationPort() );
  if ( protocol.isEmpty() )
    list << i18n("UDP protocol field", "Destination port: %1").arg( destinationPort() );
  else
    list << i18n("UDP protocol field", "Destination port: %1 (%2)").arg( destinationPort() ).arg( protocol );

  list << i18n("UDP protocol field", "Length: %1").arg( length() );
  list << i18n("UDP protocol field", "Checksum: 0x%1").arg( checksum(), 0, 16 );

  return list;
}

==> ksniffer_0.3.2.orig.tar.gz: ksniffer-0.3.2.orig/ksniffer/protocols/udp-protocol.cpp <==
/***************************************************************************
 *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
 *   giovanni@ksniffer.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA  02110-1301, USA.          *
 ***************************************************************************/

#include <netinet/in.h>

#include <qstringlist.h>

#include <klocale.h>

#include "udp-protocol.h"
#include "portnumbernamelist.h"
#include "../packet.h"
#include "../packetstructures.h"

UdpProtocol::UdpProtocol()
{
  m_packet = NULL;
  m_udp = (struct UdpHdr *) NULL;
  m_portNumberNameList = NULL;
}


UdpProtocol::UdpProtocol(Packet *packet, PortNumberNameList *ppnl)
{
  m_packet = packet;
  m_udp = (struct UdpHdr *) m_packet;
  m_portNumberNameList = ppnl;
}


void UdpProtocol::setPacket(Packet *packet)
{
  m_packet = packet;
  m_udp = (struct UdpHdr *) m_packet;
}


u_int16_t UdpProtocol::sourcePort() const
{
  return ntohs(m_udp->uh_sport);
}


u_int16_t UdpProtocol::destinationPort() const
{
  return ntohs(m_udp->uh_dport);
}


u_int16_t UdpProtocol::length() const
{
  return ntohs(m_udp->uh_ulen);
}


u_int16_t UdpProtocol::checksum() const
{
  return ntohs(m_udp->uh_sum);
}


QString UdpProtocol::protocolName() const
{
  return "UDP";
}


QString UdpProtocol::strInfo() const
{
  return QString("%1 > %2 Len=%3")
      .arg(sourcePort()).arg(destinationPort())
      .arg(length());
}


QStringList UdpProtocol::headerLines() const
{
  QStringList list;
  QString portNumberName;

  portNumberName = m_portNumberNameList->detectPortNumberName( sourcePort() );
  if ( portNumberName.isEmpty() )
    list << i18n("UDP protocol field", "Source port: %1").arg( sourcePort() );
  else
    list << i18n("UDP protocol field", "Source port: %1 (%2)").arg( sourcePort() ).arg( portNumberName );

  portNumberName = m_portNumberNameList->detectPortNumberName( destinationPort() );
  if ( portNumberName.isEmpty() )
    list << i18n("UDP protocol field", "Destination port: %1").arg( destinationPort() );
  else
    list << i18n("UDP protocol field", "Destination port: %1 (%2)").arg( destinationPort() ).arg( portNumberName );

  list << i18n("UDP protocol field", "Length: %1").arg( length() );
  list << i18n("UDP protocol field", "Checksum: 0x%1").arg( checksum(), 0, 16 );

  return list;
}
